'use client';

import {
  Box,
  Container,
  Divider,
  Flex,
  HStack,
  IconButton,
  Link,
  Stack,
  Text,
  useColorModeValue,
} from '@chakra-ui/react';
import { FaFacebook, FaTwitter, FaInstagram, FaLinkedin } from 'react-icons/fa';

import { footerLinks } from '@/app/constants/footerLinks';

const Footer = () => {
  const bg = 'black';
  const color = 'gray.300';

  return (
    <Box bg={bg} color={color} pt={10} >
      <Container maxW="1200px" px={4}>
        {/* Top row with links */}
        <Flex
          direction={{ base: 'column', md: 'row' }}
          justify="space-between"
          align={{ base: 'flex-start', md: 'flex-start' }}
          wrap="wrap"
          gap={6}
          mb={10}
        >
          {Object.entries(footerLinks).map(([title, links]) => (
            <Box key={title} minW={{ base: '100%', md: '150px' }}>
              <Text fontWeight="bold" mb={3} fontSize="lg">
                {title}
              </Text>
              <Stack spacing={2}>
                {links.map((linkText, idx) => (
                  <Link key={idx} href="#" _hover={{ textDecoration: 'underline' }}>
                    {linkText}
                  </Link>
                ))}
              </Stack>
            </Box>
          ))}
        </Flex>

        {/* Divider */}
        <Divider mb={6} borderColor={useColorModeValue('gray.700', 'gray.700')} />

        {/* Bottom row */}
        <Flex
          direction={{ base: 'column', md: 'row' }}
          justify="space-between"
          align="center"
          gap={4}
          textAlign={{ base: 'center', md: 'left' }}
          fontSize="sm"
          pb={6}
        >
          {/* Left side links */}
          <HStack spacing={6} justify={{ base: 'center', md: 'flex-start' }} w={{ base: '100%', md: 'auto' }}>
            <Link href="/terms-of-service" _hover={{ textDecoration: 'underline' }}>
              Terms & Conditions
            </Link>
            <Link href="/privacy-policy" _hover={{ textDecoration: 'underline' }}>
              Privacy Policy
            </Link>
          </HStack>

          {/* Center social icons */}
          <HStack spacing={4} justify="center" flex="1" my={{ base: 4, md: 0 }}>
            <IconButton aria-label="Facebook" icon={<FaFacebook />}  />
            <IconButton aria-label="Twitter" icon={<FaTwitter />}  />
            <IconButton aria-label="Instagram" icon={<FaInstagram />} />
            <IconButton aria-label="LinkedIn" icon={<FaLinkedin />}  />
          </HStack>

          {/* Right text */}
          <Text w={{ base: '100%', md: 'auto' }} textAlign={{ base: 'center', md: 'right' }}>
            © 2024 Tema Blog All rights reserved.
          </Text>
        </Flex>
      </Container>
    </Box>
  );
};

export default Footer;
